@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.0098';
+$VERSION = '2.0099';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -578,6 +578,27 @@ Deprecated, should be replaced by the respective lower case names.
 
 =back
 
+
+=head1 MULTITHREADING
+
+The multithreading capabilities of the Msql-Mysql-modules depend completely
+on the underlying C libraries: The modules are working with handle data
+only, no global variables are accessed or (to the best of my knowledge)
+thread unsafe functions are called. Thus DBD::mSQL and DBD::mysql are
+completely thread safe, if the C libraries thread safe and you don't
+share handles among threads.
+
+The obvious questions is: Are the C libraries thread safe? In the case of
+mSQL the answer is definitely "no". The C library has a concept of one
+single active connection at a time and that is not what threads like.
+
+In the case of MySQL the answer is "mostly" and, in theory, you should
+be able to get a "yes", if the C library is compiled for being thread
+safe (By default it isn't.) by passing the option -with-thread-safe-client
+to configure. See the section on I<How to make a threadsafe client> in
+the manual.
+
+
 =head1 BUGS
 
 The I<port> part of the first argument to the connect call is
@@ -645,6 +666,7 @@ get chopped of. (Tested with mysql 3.20.25 on a Linux 2.0.30 machine.)
 
 =back
 
+
 =head1 AUTHOR
 
 B<DBD::mSQL> has been primarily written by Alligator Descartes
