@@ -5,7 +5,7 @@ package Msql::Statement;
 use strict;
 use vars qw($OPTIMIZE $VERSION $AUTOLOAD);
 
-$VERSION = '1.1832';
+$VERSION = '1.1833';
 
 $OPTIMIZE = 0; # controls, which optimization we default to
 
@@ -41,12 +41,12 @@ sub maxlength  {
 		# New in 2.0: a string is longer than it should be
 		if (defined &Msql::TEXT_TYPE  &&
 		    $sth->type->[$i] == &Msql::TEXT_TYPE &&
-		    length($s) > $sth->length->[$i] + 5) {
-		    my $l = length($col);
+		    CORE::length($s) > $sth->length->[$i] + 5) {
+		    my $l = CORE::length($col);
 		    substr($s,$sth->length->[$i]) = "...($l)";
 		}
-		if (length($s) > $$result[$i]) {
-		    $$result[$i] = length($s);
+		if (CORE::length($s) > $$result[$i]) {
+		    $$result[$i] = CORE::length($s);
 		}
 	    }
 	}
@@ -107,7 +107,7 @@ sub as_string {
 	return '';
     }
     for (0..$sth->numfields-1) {
-	$l=length($sth->name->[$_]);
+	$l=CORE::length($sth->name->[$_]);
 	if ($sth->optimize  &&  $l < $sth->maxlength->[$_]) {
 	    $l= $sth->maxlength->[$_];
 	}
@@ -133,8 +133,8 @@ sub as_string {
 	    if (defined &Msql::TEXT_TYPE  &&
 		$sth->optimize &&
 		$sth->type->[$j] == &Msql::TEXT_TYPE &&
-		length($pcol) > $sth->length->[$j] + 5) {
-		my $l = length($col);
+		CORE::length($pcol) > $sth->length->[$j] + 5) {
+		my $l = CORE::length($col);
 		substr($pcol,$sth->length->[$j])="...($l)";
 	    }
 	    push(@prow, $pcol);
